﻿using Windows.Foundation;
using Windows.Foundation.Metadata;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "RichEditBox 엘리먼트 : 컨텍스트 메뉴에서 커스텀 명령 추가하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 플라이아웃 베이스 오픈시 처리하기 - FlyoutBase_Opening(sender, e)

        /// <summary>
        /// 플라이아웃 베이스 오픈시 처리하기
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void FlyoutBase_Opening(object sender, object e)
        {
            CommandBarFlyout commandBarFlyout = sender as CommandBarFlyout;

            if(commandBarFlyout.Target == this.richEditBox)
            {
                AppBarButton appBarButton = new AppBarButton
                {
                    Command = new StandardUICommand(StandardUICommandKind.Share)
                };

                commandBarFlyout.PrimaryCommands.Add(appBarButton);
            }
        }

        #endregion
        #region 리치 편집 박스 로드시 처리하기 - richEditBox_Loaded(sender, e)

        /// <summary>
        /// 리치 편집 박스 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void richEditBox_Loaded(object sender, RoutedEventArgs e)
        {
            if(ApiInformation.IsApiContractPresent("Windows.Foundation.UniversalApiContract", 7))
            {
                this.richEditBox.ContextFlyout.Opening   += FlyoutBase_Opening;
                this.richEditBox.SelectionFlyout.Opening += FlyoutBase_Opening;
            }
        }

        #endregion
        #region 리치 편집 박스 언로드시 처리하기 - richEditBox_Unloaded(sender, e)

        /// <summary>
        /// 리치 편집 박스 언로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void richEditBox_Unloaded(object sender, RoutedEventArgs e)
        {
            if(ApiInformation.IsApiContractPresent("Windows.Foundation.UniversalApiContract", 7))
            {
                this.richEditBox.SelectionFlyout.Opening -= FlyoutBase_Opening;
                this.richEditBox.ContextFlyout.Opening   -= FlyoutBase_Opening;
            }
        }

        #endregion
    }
}